      subroutine bobdays(istyr,isdoy,idd,ih,m,intsec,
     1                   intmsec,xlat,iorbno,prt)
c
c  Program to compute data day start times using the 
c  NORAD SGP4 propagator.  Propagates at 1 minute intervals
c  from 6 hours before to 6 hours after start of specified date.
c  Date is specified on the command line as 4-digit year and day of year. 
c  Searches back in time for most recent NORAD Two-Line Element file.
c
c  This program was converted into a subroutine so it can be called by
c  existing application programs.  7/22/97 J.G.W.
c
      parameter(npos=864)
      implicit real*8 (a-h,o-z)
      save  !required for IRIX compilers
      character*80 cpos,ctle
      character*12 dtyr
      character*70 icard1,icard2
      character*10 arg 	
      integer yr
      integer*4 satn
      integer*4 jd,jd1,jde	
      integer*4 intsec,intmsec
      integer*4 istyr,isdoy,idd,ih,m,iorbno,prt
      real*4 sma,spdsec,rtime
      real*4 spose(3,npos),svele(3,npos)
      real*8 tm(npos)
      real*8 rmanom8,reanom8,recc8,dkeplr
      dimension posi(3),veli(3),pose(3),vele(3)
      COMMON/ELT/R,TC,X,Y,Z,XDOT,YDOT,ZDOT
      COMMON/EPELM/AO,EO,XINCO,XNODEO,OMEGAO,XMAO,AINV,BSTAR,CNDOT,
     1       CON41,CON42,COSIO,COSIO2,EINV,EOSQ,EPOCH,OMEOSQ,
     2       OMGDT,POSQ,QO,RTEOSQ,SINIO,T,THGRO,XMDOT,XNDOT,
     3       XNO,XNODOT,XPIDOT,SATN,YR,INIT,METHOD
      common/bksgp/XMNPDA,XPDOTP,XKMPER,XKE
      common /gconst/pi,radeg,re,rem,f,omf2,omegae
c
c  Constants
      call cdata
      twopi = 2.0D0*pi
c      flt = 298.257D0    !1/f, or the inverse flattening of Earth
      esq = 1.d0 - (1.d0 - f)**2 !eccentricity of Earth squared
c
c  Obtain year, date from command line
c	call getarg(1,arg)
c	read (arg,*) istyr
c	call getarg(2,arg)
c	read (arg,*) isdoy
	jd1 = jd(istyr,1,isdoy)

c
c  Search for most recent NORAD TLE -- 30 day maximum enforced, which
c   yields about a 20 second error max (see Patt et al., 1993, NASA
c   Technical Memorandum 104566, Volume 11)
      jde = jd1
5     jde = jde - 1	
      jtst = jd1 - jde
      if (jtst .gt. 30) go to 350   !search not to exceed 30 days
      call jdate(jde,jyr,idd)
      call selfilnm(jyr,idd,ctle)
      open(22,err=300,file=ctle,status='old',form='formatted')
      go to 301   !file found
300   go to 5
301   continue
c      
c  Read NORAD Two-Line Elements file and set up SGP4 parameters
      call setsgp4(icard1,icard2,iyr,iday,iorbit,daye,dsma)
c      write(6,200)
c      write(6,400)icard1
c      write(6,400)icard2
c      write(6,*)'iyr,iday,iorbit = ',iyr,iday,iorbit
c      write(6,*)'day,dsma = ',daye,dsma
c      write(6,*)
      jde = jd(iyr,1,iday)
c
c  INITIALIZE FLAGS AND VARIABLES *
      IER=0
c
c  Set up start/end days and years -- skip ahead required number of days
c
c   Compute date
c      iyr = istyr
c      call doygrg(iyr,isdoy,leap,mo,imday,dtyr)
c      write(6,'(5x,a12)')dtyr
c
c   Reset accounting parameters
      delta = 1.0D0	  !1 minute intervals
c
c  Convert to minutes
      time = jd1 - jde + iday - daye - 0.25d0
      time = time*xmnpda
      sptime = time + 720.d0

	np = 0
c
c  MAKE INITIAL PREDICTION AT EPOCH  *
      INIT=1
      T=0.D0
      CALL SGP4(IER)
      IF(IER .GT. 0) GO TO 75
      IF((TWOPI/XNO) .GT. 225.D0) WRITE(6,775)
c
c  MAKE PREDICTION AT START TIME *
      IF (TIME .EQ. 0.D0) GO TO 55
      T=TIME
      CALL SGP4(IER)
      IF(IER .GT. 0) GO TO 75
      X = X*XKMPER
      Y = Y*XKMPER
      Z = Z*XKMPER
      XDOT = XDOT*XKMPER*XKE/60.D0
      YDOT = YDOT*XKMPER*XKE/60.D0
      ZDOT = ZDOT*XKMPER*XKE/60.D0
      go to 60
c
   55 T=T+DELTA
      IF(ABS(T-TIME) .GT. ABS(SPTIME-TIME)) T=SPTIME
      CALL SGP4(IER)
      IF(IER .GT. 0) GO TO 75
      X = X*XKMPER
      Y = Y*XKMPER
      Z = Z*XKMPER
      XDOT = XDOT*XKMPER*XKE/60.D0
      YDOT = YDOT*XKMPER*XKE/60.D0
      ZDOT = ZDOT*XKMPER*XKE/60.D0
      day = daye + t/xmnpda
c      iday = iday  + np/86400.0D0

c   Compute Greenwich Hour Angle
60    call gha2000(iyr,day,gha)
c   Compute Earth-centered Earth-fixed coordinates
      posi(1) = x
      posi(2) = y
      posi(3) = z
      veli(1) = xdot
      veli(2) = ydot
      veli(3) = zdot
      call ecef(gha,posi,veli,pose,vele)

      np = np+1
c      type *,np,pose
      do i = 1,3
       spose(i,np) = pose(i)
       svele(i,np) = vele(i)
      enddo
      isec = np-1
      tm(np) = t

      IF(ABS(T-TIME) .LT. ABS(SPTIME-TIME)) GO TO 55
	ppz = 1.d10
	do i=2,np
	  if ((spose(2,i-1).lt.0.).and.(spose(2,i).gt.0.).and.
     *       (spose(1,i).lt.0.).and.(svele(3,i).lt.0.)) then
	    t = tm(i-1) - spose(2,i-1)*(tm(i)-tm(i-1))/
     *         (spose(2,i)-spose(2,i-1))
	    px = spose(1,i-1) - spose(2,i-1)*(spose(1,i)-spose(1,i-1))/
     *         (spose(2,i)-spose(2,i-1))
	    pz = spose(3,i-1) - spose(2,i-1)*(spose(3,i)-spose(3,i-1))/
     *         (spose(2,i)-spose(2,i-1))
	    if (abs(pz).gt.abs(ppz)) then
	      msec = h*36.d5
	      call getorbno (iy2,idd,msec,iorbno,inorad,icard1,icard2)
	      intsec = xs
	      xs = xs - intsec
	      xs = xs * 1000
	      intmsec = xs
              if (prt.eq.1) then
	         write (*,1300),idd,ih,m,intsec,intmsec,xlat,iorbno
 1300	         format(i10.3,4x,2(i2.2,':'),i2.2,'.',i3.3,10x,f10.4,i10)
              end if
c
	      go to 999
	   end if
	      xlat = atand(pz/(-px*omf2))
	      day = daye + t/xmnpda
	      iday = day
	      jd1 = jd(iyr,1,iday)
	      call jdate(jd1,iy2,idd)
	      h = 24.*(day - iday)
	      ih = h
	      xm = 60.*(h-ih)
	      m = xm
	      xs = 60*(xm-m)
	      ppz = pz
	      
	  end if
	end do
      
      go to 999
c
   75 WRITE(6,*)'***SGP4 ERROR-BAD INPUT ELEMENTS OR PAST DECAY***'
      go to 999
c
c  File does not exist
350   write(6,*)
      write(6,*)'                  ERROR  '
      write(6,*)
      write(6,*)' RECENT NORAD TWO LINE ELEMENT FILE NOT FOUND'
      write(6,*)'               FOR SEASTAR: '
      write(6,*)' File does not exist or most recent file'
      write(6,*)'          exceeds 30 days old'
      write(6,*)'       Obtain updated element file'
c
999   continue
c
  200 format(1H1,' 2-LINE ELEMENT SET  (TRANSMISSION FORMAT)')
  400 format(1X,A70)
  500 FORMAT(I1,1X,I5,1X,A10,I2,D12.0,1X,D10.0,1X,F6.5,I2,1X,F6.5,I2,
     1       1X,I1,1X,I4)
  600 FORMAT(I1,7X,D8.0,1X,D8.0,1X,F7.7,1X,D8.0,1X,D8.0,1X,D11.0,I5)
  775 FORMAT('PERIOD > 225 MIN - DEEP SPACE PERTURBATIONS APPLIED',/)
  800 FORMAT(i10,3F10.2,3F10.3)
 1000 format(2f10.4)
c
      end
