      subroutine setsgp4(icard1,icard2,iyr,iday,iorbit,rday,dsma)
c
c  Read NORAD Two-Line Elements and sets up SGP4.
c
c  Modifications by Watson Gregg, GSFC
c***********************************************************************
c                                                                      *
c                              W A R N I N G                           *
c                                                                      *
c  THIS SOFTWARE CONTAINS TECHNICAL DATA WHOSE EXPORT IS RESTRICTED BY *
c  THE ARMS EXPORT CONTROL ACT (TITLE 22, USC, SEC 2751 ) OR EXECUTIVE *
c  ORDER 12470.  VIOLATORS OF THE EXPORT LAWS ARE SUBJECT TO SEVERE    *
c  CRIMINAL PENALTIES.                                                 *
c                                                                      *
c                         D I S T R I B U T I O N                      *
c                                                                      *
c  DISTRIBUTION IS AUTHORIZED TO US GOVERNMENT AGENCIES AND THEIR      *
c  CONTRACTORS ON A NEED TO KNOW BASIS ONLY.  OTHER REQUESTS FOR THIS  *
c  SOFTWARE SHALL BE REFERRED TO AFSPACECOM/CN                       *
c                                                                      *
c***********************************************************************
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      save  !required for IRIX compilers
      CHARACTER*70 ICARD1,icard2
      CHARACTER*8 SATNM
      INTEGER ELNO,EPHTYP,REVI,YR
      INTEGER*4 SATN
      COMMON/ELT/R,TC,X,Y,Z,XDOT,YDOT,ZDOT
      COMMON/EPELM/AO,EO,XINCO,XNODEO,OMEGAO,XMAO,AINV,BSTAR,CNDOT,
     1       CON41,CON42,COSIO,COSIO2,EINV,EOSQ,EPOCH,OMEOSQ,
     2       OMGDT,POSQ,QO,RTEOSQ,SINIO,T,THGRO,XMDOT,XNDOT,
     3       XNO,XNODOT,XPIDOT,SATN,YR,init,method
      common/bksgp/XMNPDA,XPDOTP,XKMPER,XKE

c  SET MATHEMATICAL CONSTANTS *
      DE2RA=1.745329251994330D-2
      TWOPI=6.283185307179586D0
c
c  SET PHYSICAL CONSTANTS *
      XMNPDA=1440.D0
      XPDOTP=229.1831180523293D0
      XKMPER=6378.135D0
      XKE=7.43669161331734132D-2

cc  Get elements file name
c      WRITE(6,*)
c      OPEN(22,ERR=12,FILE=ctle,STATUS='OLD')  ! opened before

c  READ INPUT FILE  *
c      WRITE(6,650)
c      WRITE(6,675)
c      WRITE(6,*)
      READ(22,300) ICARD1

c  READ THE FIRST LINE OF ELEMENT SET  *
      READ(ICARD1,500) ICRDNO,SATN,SATNM,YR,RDAY,XNDOT,XN2DT,
     *IE,BTERM,IE2,EPHTYP,ELNO
c   CONVERT TO INTERNAL UNITS  *
c    (DISTANCE IN EARTH RADII, AND VELOCITY IN ER/KEMIN)
      XN2DT=XN2DT*1.D1**IE
      XNDOT=XNDOT/(XPDOTP*XMNPDA)
      XN2DT=XN2DT/(XPDOTP*XMNPDA*XMNPDA)
      BTERM=BTERM*1.D1**IE2
      BSTAR=BTERM

c  READ THE SECOND LINE OF ELEMENT SET  *
      READ(22,300) ICARD2
      READ(ICARD2,600) ICRDNO,XINCO,XNODEO,EO,OMEGAO,XMAO,XNO,REVI
c   CONVERT TO INTERNAL UNITS  *
c    (ANGLES IN RADIANS)
      revday = xno
      XNO=XNO/XPDOTP
      XINCO=XINCO*DE2RA
      XNODEO=XNODEO*DE2RA
      OMEGAO=OMEGAO*DE2RA
      XMAO=XMAO*DE2RA
      EPOCH=(YR-50)*365+(YR-49)/4+RDAY
c
c  Convert year to four-digits, spanning 1950 to 2049
      if (yr .lt. 50)then
       iyr = 2000 + yr
      else
       iyr = 1900 + yr
      endif
c
c  Convert days, orbits to integers
      iday = rday
      iorbit = revi
c
c  Compute semi-major axis using method of SGP4
      bj2 = 0.108263D-02         !J2 term 
      if (revday .gt. 1.0D-10)then     !trap for divide by zero
       rxno = revday*twopi/1440.0D0  !mean motion in radians/minute
       tothrd = 2.0D0/3.0D0
       CK2 = abs(0.5D0*bj2)    !   1/2 * J2 * AE ** 2
       A1 = (XKE/rxno)**TOTHRD
       COSI = DCOS(xinco)
       THETA2 = COSI*COSI
       X3THM1 = 3.0D0*THETA2-1.0D0
       EOSQU = EO*EO
       BETAO2 = 1.0D0-EOSQU
       BETAO = DSQRT(BETAO2)
       DEL1 = 1.5D0*CK2*X3THM1/(A1*A1*BETAO*BETAO2)
       A2 = A1*(1.0D0-DEL1*(0.5D0*TOTHRD+DEL1*
     *       (1.0D0+134.0D0/81.0D0*DEL1)))
       DELO = 1.5D0*CK2*X3THM1/(A2*A2*BETAO*BETAO2)
       XNODP = rxno/(1.0D0+DELO)
       A2DP = A2/(1.0D0-DELO) !semi-major axis in Earth radii
       dsma = a2dp*6378.137D0         !semi-major axis in km
      else
       write(6,*)'Semi-Major Axis Not Available'
       write(6,*)'Default to Nominal Altitude (705 km)'
       dsma = 705.0D0+6378.137D0
      endif
c
      GO TO 999
c
c
  300 FORMAT(A70)
  500 FORMAT(I1,1X,I5,1X,A10,I2,D12.0,1X,D10.0,1X,F6.5,I2,1X,F6.5,I2,
     1       1X,I1,1X,I4)
  600 FORMAT(I1,7X,D8.0,1X,D8.0,1X,F7.7,1X,D8.0,1X,D8.0,1X,D11.0,I5)
  650 FORMAT(' EPHEMERIS GENERATED BY SGP4 USING WGS-72 EARTH MODEL')
  675 FORMAT(' COORDINATE FRAME=TRUE EQUATOR AND MEAN EQUINOX OF EPOCH',
     1       /,' USING THE FK5 MEAN OF J2000 TIME AND REFERENCE FRAME')
  12  write(6,*)'Element file not found'
  999 CLOSE(22)
      return
      END
